@@ -50,7 +50,7 @@ async def get_hfox(id: int = choose().hentaifox):
             f.write(r.content)
      
             if os.path.exists(neat_dir + '/' + img_name):
-                print(f'Successfully downloaded {img_name} | {get_size(neat_dir + "/" + img_name)} MB | in {time.time() - start:.2f} seconds')
+                print(f'Successfully downloaded {img_name} | {get_size(neat_dir + "/" + img_name)} MB | took {time.time() - start:.2f} seconds')
             
             if len(img) == len(os.listdir(neat_dir)):
                 print(f'Successfully downloaded all images in {(time.time() - initial) / 60:.2f} minutes')
