@@ -40,7 +40,7 @@ async def get_sim(id: str = choose().simply):
             if os.path.exists(f"{neat_dir}/{i+1}.jpg"):
                 file = get_size(f"{neat_dir}/{i+1}.jpg")
                 print(
-                    f'Successfully downloaded {i+1} | {file} MB | in {time.time() - start:.2f} seconds')
+                    f'Successfully downloaded {i+1} | {file} MB | took {time.time() - start:.2f} seconds')
 
             if len(img) == len(os.listdir(neat_dir)):
                 ## print time elapsed as minutes not second
